@@ -1,6 +1,7 @@
-__all__ = ["anomaly", "classifier", "clustering", "graph", "nearest_neighbor", "recommender", "regression", "stat", ]
+__all__ = ["anomaly", "burst", "classifier", "clustering", "graph", "nearest_neighbor", "recommender", "regression", "stat", ]
 
 from jubatus.anomaly.client import Anomaly
+from jubatus.burst.client import Burst
 from jubatus.classifier.client import Classifier
 from jubatus.clustering.client import Clustering
 from jubatus.graph.client import Graph
